pub struct Point {
pub row: usize,
pub column: usize,
}Expand description
A position within a text document.
The position is represented by a zero-based row and column.
The exact meaning of column depends on the document’s coordinate
system, such as byte offset, character offset, or display column.
Fields
row: usizeThe zero-based row of the position.
column: usizeThe zero-based column of the position.
Implementations