AutoPairsHook

Struct AutoPairsHook 

pub struct AutoPairsHook;
Built-in hook that automatically inserts closing quotes, brackets, and braces, wraps selected text, and steps over closing pairs.

Implementations

Source

impl AutoPairsHook

pub fn new() -> Self

Creates a new auto-pairs hook.