pub enum ConcealMode {
Off,
Dimmed,
Hidden,
}Expand description
Display mode for markdown syntax delimiters (like # , **, *, ~~, `) on inactive lines.
Variants
Off
Markdown markers are always visible with normal syntax coloring.
Dimmed
Markdown markers on inactive lines are rendered with faint opacity.
Hidden
Markdown markers on inactive lines are completely hidden (invisible).