TextStyle

Struct TextStyle 

pub struct TextStyle {
    pub color: Option<Rgba>,
    pub background: Option<Rgba>,
    pub bold: bool,
    pub italic: bool,
    pub underline: Option<UnderlineDecoration>,
    pub strikethrough: bool,
}
Direct styling attributes for a span of text.

Fields

color: Option<Rgba>

Text foreground color.

background: Option<Rgba>

Background highlight color.

bold: bool

Whether the text is rendered in bold font weight.

italic: bool

Whether the text is rendered in italic font style.

underline: Option<UnderlineDecoration>

Underline decoration style if any.

strikethrough: bool

Strikethrough line through the text.

Implementations

Source

impl TextStyle

pub const fn new() -> Self

Creates an empty text style with all attributes set to default.

pub const fn color(self, color: Rgba) -> Self

Sets foreground color.

pub const fn background(self, background: Rgba) -> Self

Sets background color.

pub const fn bold(self) -> Self

Sets bold attribute.

pub const fn italic(self) -> Self

Sets italic attribute.

pub const fn underline(self, underline: UnderlineDecoration) -> Self

Sets underline attribute.

pub const fn strikethrough(self) -> Self

Sets strikethrough attribute.