pub struct AutoPairsHook;Expand description
Built-in hook that automatically inserts closing quotes, brackets, and braces, wraps selected text, and steps over closing pairs.
Implementations
Sourceimpl AutoPairsHook
impl AutoPairsHook