pub struct TextStyle {
pub color: Option<Rgba>,
pub background: Option<Rgba>,
pub bold: bool,
pub italic: bool,
pub underline: Option<UnderlineDecoration>,
pub strikethrough: bool,
}Expand description
Direct styling attributes for a span of text.
Fields
color: Option<Rgba>Text foreground color.
background: Option<Rgba>Background highlight color.
bold: boolWhether the text is rendered in bold font weight.
italic: boolWhether the text is rendered in italic font style.
underline: Option<UnderlineDecoration>Underline decoration style if any.
strikethrough: boolStrikethrough line through the text.
Implementations
Sourceimpl TextStyle
impl TextStyle
Sourcepub const fn background(self, background: Rgba) -> Self
pub const fn background(self, background: Rgba) -> Self
Sets background color.
Sourcepub const fn underline(self, underline: UnderlineDecoration) -> Self
pub const fn underline(self, underline: UnderlineDecoration) -> Self
Sets underline attribute.
Sourcepub const fn strikethrough(self) -> Self
pub const fn strikethrough(self) -> Self
Sets strikethrough attribute.